@@ -5,13 +5,13 @@ pub struct Message {
     /// The ID of the message
     ///
     /// 128 bit unsigned integer
-    id: u128,
+    pub id: u128,
 
     /// The content of the message
     ///
     /// String of max length 10,240 characters
-    content: String,
+    pub content: String,
 
     /// The channel this message is in
-    channel: Channel,
+    pub channel: Channel,
 }
